@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -164,6 +164,12 @@ public class FormatData_fi extends ListResourceBundle {
                "H.mm.ss",
                "H.mm",
             };
+        final String[] metaValue_DateTimePatterns = new String[] {
+               "{1} 'klo' {0}",
+               "{1} 'klo' {0}",
+               "{1} 'klo' {0}",
+               "{1} {0}",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -234,17 +240,11 @@ public class FormatData_fi extends ListResourceBundle {
                     "j\u00e4lkeen Kristuksen syntym\u00e4n",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} 'klo' {0}",
-                    "{1} 'klo' {0}",
-                    "{1} 'klo' {0}",
-                    "{1} {0}",
-                }
-            },
+            { "DateTimePatterns", metaValue_DateTimePatterns },
             { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -259,6 +259,8 @@ public class FormatData_fi extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "ep\u00e4luku",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -286,6 +288,7 @@ public class FormatData_fi extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kiinan tasavallan kalenteri" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -294,13 +297,6 @@ public class FormatData_fi extends ListResourceBundle {
             { "field.second", "sekunti" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamilainen kalenteri" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -330,18 +326,18 @@ public class FormatData_fi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tuhat",
-                    "00 tuhatta",
-                    "000 tuhatta",
-                    "0 miljoona",
-                    "00 miljoonaa",
-                    "000 miljoonaa",
-                    "0 miljardi",
-                    "00 miljardia",
-                    "000 miljardia",
-                    "0 biljoona",
-                    "00 biljoonaa",
-                    "000 biljoonaa",
+                    "{one:0' 'tuhat other:0' 'tuhatta}",
+                    "{one:00' 'tuhatta other:00' 'tuhatta}",
+                    "{one:000' 'tuhatta other:000' 'tuhatta}",
+                    "{one:0' 'miljoona other:0' 'miljoonaa}",
+                    "{one:00' 'miljoonaa other:00' 'miljoonaa}",
+                    "{one:000' 'miljoonaa other:000' 'miljoonaa}",
+                    "{one:0' 'miljardi other:0' 'miljardia}",
+                    "{one:00' 'miljardia other:00' 'miljardia}",
+                    "{one:000' 'miljardia other:000' 'miljardia}",
+                    "{one:0' 'biljoona other:0' 'biljoonaa}",
+                    "{one:00' 'biljoonaa other:00' 'biljoonaa}",
+                    "{one:000' 'biljoonaa other:000' 'biljoonaa}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -393,6 +389,7 @@ public class FormatData_fi extends ListResourceBundle {
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "viikko" },
+            { "buddhist.DateTimePatterns", metaValue_DateTimePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
@@ -405,18 +402,18 @@ public class FormatData_fi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0t'.'",
-                    "00\u00a0t'.'",
-                    "000\u00a0t'.'",
-                    "0\u00a0milj'.'",
-                    "00\u00a0milj'.'",
-                    "000\u00a0milj'.'",
-                    "0\u00a0mrd'.'",
-                    "00\u00a0mrd'.'",
-                    "000\u00a0mrd'.'",
-                    "0\u00a0bilj'.'",
-                    "00\u00a0bilj'.'",
-                    "000\u00a0bilj'.'",
+                    "{one:0\u00a0t'.' other:0\u00a0t'.'}",
+                    "{one:00\u00a0t'.' other:00\u00a0t'.'}",
+                    "{one:000\u00a0t'.' other:000\u00a0t'.'}",
+                    "{one:0\u00a0milj'.' other:0\u00a0milj'.'}",
+                    "{one:00\u00a0milj'.' other:00\u00a0milj'.'}",
+                    "{one:000\u00a0milj'.' other:000\u00a0milj'.'}",
+                    "{one:0\u00a0mrd'.' other:0\u00a0mrd'.'}",
+                    "{one:00\u00a0mrd'.' other:00\u00a0mrd'.'}",
+                    "{one:000\u00a0mrd'.' other:000\u00a0mrd'.'}",
+                    "{one:0\u00a0bilj'.' other:0\u00a0bilj'.'}",
+                    "{one:00\u00a0bilj'.' other:00\u00a0bilj'.'}",
+                    "{one:000\u00a0bilj'.' other:000\u00a0bilj'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -462,6 +459,14 @@ public class FormatData_fi extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
