@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -140,66 +140,32 @@ public class FormatData_fr_CA extends ListResourceBundle {
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0} (heure normale)" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "roc.DatePatterns",
-                new String[] {
-                    "GGGG y MMMM d, EEEE",
-                    "GGGG y MMMM d",
-                    "GGGG y MMM d",
-                    "yy-MM-dd G",
-                }
-            },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.DayNarrows",
-                new String[] {
-                    "D",
-                    "L",
-                    "M",
-                    "M",
-                    "J",
-                    "V",
-                    "S",
-                }
-            },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_narrow_Eras },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.roc.DatePatterns",
-                new String[] {
-                    "G y MMMM d, EEEE",
-                    "G y MMMM d",
-                    "G y MMM d",
-                    "yy-MM-dd GGGGG",
-                }
-            },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "",
-                    "",
-                    "",
-                    "0\u00a0M",
-                    "",
-                    "",
-                    "0\u00a0G",
-                    "00\u00a0G",
-                    "000\u00a0G",
-                    "0\u00a0T",
-                    "00\u00a0T",
-                    "000\u00a0T",
-                    "",
-                    "0\u00a0k",
+                    "{one:0\u00a0k other:0\u00a0k}",
+                    "{one:00\u00a0k other:00\u00a0k}",
+                    "{one:000\u00a0k other:000\u00a0k}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0\u00a0G other:0\u00a0G}",
+                    "{one:00\u00a0G other:00\u00a0G}",
+                    "{one:000\u00a0G other:000\u00a0G}",
+                    "{one:0\u00a0T other:0\u00a0T}",
+                    "{one:00\u00a0T other:00\u00a0T}",
+                    "{one:000\u00a0T other:000\u00a0T}",
                 }
             },
             { "timezone.regionFormat.daylight", "{0} (heure avanc\u00e9e)" },
@@ -208,7 +174,7 @@ public class FormatData_fr_CA extends ListResourceBundle {
                     "EEEE d MMMM y",
                     "d MMMM y",
                     "d MMM y",
-                    "yy-MM-dd",
+                    "y-MM-dd",
                 }
             },
             { "java.time.islamic.DatePatterns",
@@ -244,6 +210,8 @@ public class FormatData_fr_CA extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -254,20 +222,31 @@ public class FormatData_fr_CA extends ListResourceBundle {
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "",
-                    "",
-                    "",
-                    "0 million",
-                    "00 million",
-                    "",
-                    "",
-                    "",
-                    "0 mille",
+                    "{one:0' 'mille other:0' 'mille}",
+                    "{one:00' 'mille other:00' 'mille}",
+                    "{one:000' 'mille other:000' 'mille}",
+                    "{one:0' 'million other:0' 'millions}",
+                    "{one:00' 'million other:00' 'millions}",
+                    "{one:000' 'million other:000' 'millions}",
+                    "{one:0' 'milliard other:0' 'milliards}",
+                    "{one:00' 'milliard other:00' 'milliards}",
+                    "{one:000' 'milliard other:000' 'milliards}",
+                    "{one:0' 'billion other:0' 'billions}",
+                    "{one:00' 'billion other:00' 'billions}",
+                    "{one:000' 'billion other:000' 'billions}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
