@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -166,6 +166,10 @@ public class FormatData_hr extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
@@ -182,9 +186,21 @@ public class FormatData_hr extends ListResourceBundle {
                "d. MMM y. GGGG",
                "dd. MM. y. G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "poslije Krista",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "po. Kr.",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
             };
         final String[] metaValue_java_time_japanese_DatePatterns = new String[] {
                "EEEE, d. MMMM y. G",
@@ -202,11 +218,16 @@ public class FormatData_hr extends ListResourceBundle {
                "prije R.O.C.",
                "R.O.C.",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "gregorijanski kalendar";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "godina" },
             { "calendarname.islamic-umalqura", "islamski kalendar (Umm al-Qura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_japanese_DatePatterns },
             { "standalone.QuarterAbbreviations",
@@ -220,7 +241,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "islamski civilni kalendar" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
@@ -234,6 +255,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "prije Krista",
@@ -265,20 +287,26 @@ public class FormatData_hr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_japanese_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuta" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "era" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "kalendar Republike Kine" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "mjesec" },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "sekunda" },
             { "islamic.MonthNarrows",
@@ -300,18 +328,11 @@ public class FormatData_hr extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamski kalendar" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.CompactNumberPatterns",
@@ -319,22 +340,22 @@ public class FormatData_hr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tisu\u0107a",
-                    "00 tisu\u0107a",
-                    "000 tisu\u0107a",
-                    "0 milijun",
-                    "00 milijun",
-                    "000 milijun",
-                    "0 milijarda",
-                    "00 milijarda",
-                    "000 milijarda",
-                    "0 bilijun",
-                    "00 bilijun",
-                    "000 bilijun",
+                    "{one:0' 'tisu\u0107a few:0' 'tisu\u0107e other:0' 'tisu\u0107a}",
+                    "{one:00' 'tisu\u0107a few:00' 'tisu\u0107e other:00' 'tisu\u0107a}",
+                    "{one:000' 'tisu\u0107a few:000' 'tisu\u0107e other:000' 'tisu\u0107a}",
+                    "{one:0' 'milijun few:0' 'milijuna other:0' 'milijuna}",
+                    "{one:00' 'milijun few:00' 'milijuna other:00' 'milijuna}",
+                    "{one:000' 'milijun few:000' 'milijuna other:000' 'milijuna}",
+                    "{one:0' 'milijarda few:0' 'milijarde other:0' 'milijardi}",
+                    "{one:00' 'milijarda few:00' 'milijarde other:00' 'milijardi}",
+                    "{one:000' 'milijarda few:000' 'milijarde other:000' 'milijardi}",
+                    "{one:0' 'bilijun few:0' 'bilijuna other:0' 'bilijuna}",
+                    "{one:00' 'bilijun few:00' 'bilijuna other:00' 'bilijuna}",
+                    "{one:000' 'bilijun few:000' 'bilijuna other:000' 'bilijuna}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -351,14 +372,15 @@ public class FormatData_hr extends ListResourceBundle {
                     "s",
                 }
             },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "vremenska zona" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras",
                 new String[] {
                     "pr. Kr.",
@@ -373,6 +395,8 @@ public class FormatData_hr extends ListResourceBundle {
             { "field.weekday", "dan u tjednu" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -381,6 +405,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "tjedan" },
@@ -388,7 +413,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -396,18 +421,18 @@ public class FormatData_hr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tis'.'",
-                    "00\u00a0tis'.'",
-                    "000\u00a0tis'.'",
-                    "0\u00a0mil'.'",
-                    "00\u00a0mil'.'",
-                    "000\u00a0mil'.'",
-                    "0\u00a0mlr'.'",
-                    "00\u00a0mlr'.'",
-                    "000\u00a0mlr'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0tis'.' few:0\u00a0tis'.' other:0\u00a0tis'.'}",
+                    "{one:00\u00a0tis'.' few:00\u00a0tis'.' other:00\u00a0tis'.'}",
+                    "{one:000\u00a0tis'.' few:000\u00a0tis'.' other:000\u00a0tis'.'}",
+                    "{one:0\u00a0mil'.' few:0\u00a0mil'.' other:0\u00a0mil'.'}",
+                    "{one:00\u00a0mil'.' few:00\u00a0mil'.' other:00\u00a0mil'.'}",
+                    "{one:000\u00a0mil'.' few:000\u00a0mil'.' other:000\u00a0mil'.'}",
+                    "{one:0\u00a0mlr'.' few:0\u00a0mlr'.' other:0\u00a0mlr'.'}",
+                    "{one:00\u00a0mlr'.' few:00\u00a0mlr'.' other:00\u00a0mlr'.'}",
+                    "{one:000\u00a0mlr'.' few:000\u00a0mlr'.' other:000\u00a0mlr'.'}",
+                    "{one:0\u00a0bil'.' few:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' few:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' few:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -427,13 +452,14 @@ public class FormatData_hr extends ListResourceBundle {
                 new String[] {
                     "{1} {0}",
                     "{1} {0}",
-                    "",
-                    "",
+                    "{1} {0}",
+                    "{1} {0}",
                 }
             },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "sat" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "budisti\u010dki kalendar" },
             { "standalone.MonthNames",
                 new String[] {
@@ -452,11 +478,21 @@ public class FormatData_hr extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
