@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -266,7 +266,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "HU", "Ungverjaland" },
             { "tmh", "tamasjek" },
             { "IC", "Kanar\u00edeyjar" },
-            { "nan", "nan" },
             { "ID", "Ind\u00f3nes\u00eda" },
             { "peo", "fornpersneska" },
             { "IE", "\u00cdrland" },
@@ -507,7 +506,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "hai", "ha\u00edda" },
             { "035", "Su\u00f0austur-As\u00eda" },
             { "UG", "\u00daganda" },
-            { "hak", "hak" },
             { "type.co.pinyin", "Pinyin-r\u00f6\u00f0un" },
             { "039", "Su\u00f0ur-Evr\u00f3pa" },
             { "Sinh", "sinhala" },
@@ -710,7 +708,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.latn", "Vestr\u00e6nar t\u00f6lur" },
             { "Hant", "hef\u00f0bundi\u00f0" },
             { "ff", "f\u00fala" },
-            { "hsn", "hsn" },
             { "fi", "finnska" },
             { "fj", "f\u00eddjeyska" },
             { "fon", "f\u00f3n" },
@@ -773,7 +770,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "ka", "georg\u00edska" },
             { "bla", "siksika" },
             { "mak", "makasar" },
-            { "wuu", "wuu" },
             { "sms", "skoltesam\u00edska" },
             { "man", "manding\u00f3" },
             { "kg", "kong\u00f3ska" },
@@ -1036,6 +1032,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tam\u00edlskar t\u00f6lur" },
             { "krc", "karasa\u00edbalkar" },
             { "inh", "ing\u00fas" },
+            { "fa_AF", "dar\u00ed" },
             { "krl", "kar\u00e9lska" },
             { "efi", "ef\u00edk" },
             { "key.nu", "T\u00f6lur" },
